@@ -1,4 +1,4 @@
-/* $Id: libgnomevfsmm.h,v 1.8 2003/12/22 17:11:59 murrayc Exp $ */
+/* $Id: libgnomevfsmm.h,v 1.9 2004/03/02 09:58:03 murrayc Exp $ */
 /* libgnomevfsmm - a C++ wrapper for libgda
  *
  * Copyright 1999-2003 Free Software Foundation
@@ -30,6 +30,8 @@ extern const int libgnomevfsmm_micro_version;
 
 #include <libgnomevfsmm/init.h>
 #include <libgnomevfsmm/application-registry.h>
+#include <libgnomevfsmm/async.h>
+#include <libgnomevfsmm/async-handle.h>
 #include <libgnomevfsmm/enums.h>
 #include <libgnomevfsmm/types.h>
 #include <libgnomevfsmm/directory-handle.h>
@@ -43,5 +45,8 @@ extern const int libgnomevfsmm_micro_version;
 #include <libgnomevfsmm/monitor-handle.h>
 #include <libgnomevfsmm/transfer-progress.h>
 #include <libgnomevfsmm/transfer.h>
+#include <libgnomevfsmm/drive.h>
+#include <libgnomevfsmm/volume.h>
+#include <libgnomevfsmm/volume-monitor.h>
 
 #endif /* #ifndef LIBGNOMEVFSMM_H */
